@@ -49,9 +49,9 @@ from debian.deb822 import Deb822
 from .reformatting import FormattingUnpreservable
 
 
-__version__ = (0, 39)
+__version__ = (0, 40)
 version_string = '.'.join(map(str, __version__))
-SUPPORTED_CERTAINTIES = ['certain', 'possible', None]
+SUPPORTED_CERTAINTIES = ['certain', 'likely', 'possible', None]
 DEFAULT_MINIMUM_CERTAINTY = 'certain'
 USER_AGENT = 'lintian-brush/' + version_string
 # Too aggressive?
@@ -189,6 +189,18 @@ def parse_script_fixer_output(text):
     return FixerResult('\n'.join(lines), fixed_tags, certainty)
 
 
+def determine_env(current_version, compat_release, minimum_certainty,
+                  trust_package, allow_reformatting, net_access):
+    env = dict(os.environ.items())
+    env['CURRENT_VERSION'] = str(current_version)
+    env['COMPAT_RELEASE'] = compat_release
+    env['MINIMUM_CERTAINTY'] = minimum_certainty
+    env['TRUST_PACKAGE'] = 'true' if trust_package else 'false'
+    env['REFORMATTING'] = ('allow' if allow_reformatting else 'disallow')
+    env['NET_ACCESS'] = ('allow' if net_access else 'disallow')
+    return env
+
+
 class PythonScriptFixer(Fixer):
     """A fixer that is implemented as a python script.
 
@@ -208,13 +220,13 @@ class PythonScriptFixer(Fixer):
             minimum_certainty=DEFAULT_MINIMUM_CERTAINTY,
             trust_package=False, allow_reformatting=False,
             net_access=True):
-        env = dict(os.environ.items())
-        env['CURRENT_VERSION'] = str(current_version)
-        env['COMPAT_RELEASE'] = compat_release
-        env['MINIMUM_CERTAINTY'] = minimum_certainty
-        env['TRUST_PACKAGE'] = 'true' if trust_package else 'false'
-        env['REFORMATTING'] = ('allow' if allow_reformatting else 'disallow')
-        env['NET_ACCESS'] = ('allow' if net_access else 'disallow')
+        env = determine_env(
+            current_version=current_version,
+            compat_release=compat_release,
+            minimum_certainty=minimum_certainty,
+            trust_package=trust_package,
+            allow_reformatting=allow_reformatting,
+            net_access=net_access)
         try:
             old_env = os.environ
             old_stderr = sys.stderr
@@ -274,13 +286,13 @@ class ScriptFixer(Fixer):
             minimum_certainty=DEFAULT_MINIMUM_CERTAINTY,
             trust_package=False, allow_reformatting=False,
             net_access=True):
-        env = dict(os.environ.items())
-        env['CURRENT_VERSION'] = str(current_version)
-        env['COMPAT_RELEASE'] = compat_release
-        env['MINIMUM_CERTAINTY'] = minimum_certainty
-        env['TRUST_PACKAGE'] = 'true' if trust_package else 'false'
-        env['REFORMATTING'] = ('allow' if allow_reformatting else 'disallow')
-        env['NET_ACCESS'] = ('allow' if net_access else 'disallow')
+        env = determine_env(
+            current_version=current_version,
+            compat_release=compat_release,
+            minimum_certainty=minimum_certainty,
+            trust_package=trust_package,
+            allow_reformatting=allow_reformatting,
+            net_access=net_access)
         with tempfile.SpooledTemporaryFile() as stderr:
             p = subprocess.Popen(self.script_path, cwd=basedir,
                                  stdout=subprocess.PIPE, stderr=stderr,
@@ -511,9 +523,15 @@ def certainty_sufficient(actual_certainty, minimum_certainty):
     Returns:
       boolean
     """
-    if actual_certainty == 'possible' and minimum_certainty == 'certain':
-        return False
-    return True
+    actual_confidence = certainty_to_confidence(actual_certainty)
+    if actual_confidence is None:
+        # Actual confidence is unknown.
+        # TODO(jelmer): Should we really be ignoring this?
+        return True
+    minimum_confidence = certainty_to_confidence(minimum_certainty)
+    if minimum_confidence is None:
+        return True
+    return actual_confidence <= minimum_confidence
 
 
 def check_clean_tree(local_tree):
@@ -781,4 +799,21 @@ def run_lintian_fixers(local_tree, fixers, update_changelog=True,
 
 
 def certainty_to_confidence(certainty):
+    if certainty in ('unknown', None):
+        return None
     return SUPPORTED_CERTAINTIES.index(certainty)
+
+
+def confidence_to_certainty(confidence):
+    if confidence is None:
+        return 'unknown'
+    try:
+        return SUPPORTED_CERTAINTIES[confidence]
+    except IndexError:
+        raise ValueError(confidence)
+
+
+def min_certainty(certainties):
+    return confidence_to_certainty(
+        max([certainty_to_confidence(c)
+            for c in certainties] + [0]))
