@@ -30,25 +30,25 @@ from .deb822 import update_deb822
 from .reformatting import GeneratedFile
 
 
-def dh_gnome_clean():
+def dh_gnome_clean(path='.'):
     """Run the dh_gnome_clean command.
 
     This needs to do some post-hoc cleaning, since dh_gnome_clean
     writes various debhelper log files that should not be checked in.
     """
-    for n in os.listdir('debian'):
+    for n in os.listdir(os.path.join(path, 'debian')):
         if n.endswith('.debhelper.log'):
             raise AssertionError('pre-existing .debhelper.log files')
-    subprocess.check_call(["dh_gnome_clean"])
-    for n in os.listdir('debian'):
+    subprocess.check_call(["dh_gnome_clean"], cwd=path)
+    for n in os.listdir(os.path.join(path, 'debian')):
         if n.endswith('.debhelper.log'):
-            os.unlink('debian/' + n)
+            os.unlink(os.path.join(path, 'debian', n))
 
 
-def pg_buildext_updatecontrol():
+def pg_buildext_updatecontrol(path='.'):
     """Run the 'pg_buildext updatecontrol' command.
     """
-    subprocess.check_call(["pg_buildext", "updatecontrol"])
+    subprocess.check_call(["pg_buildext", "updatecontrol"], cwd=path)
 
 
 def guess_template_type(template_path):
@@ -79,12 +79,13 @@ def _update_control_template(template_path, path, paragraph_cb):
     if not update_deb822(template_path, paragraph_cb=paragraph_cb):
         # A bit odd, since there were changes to the output file. Anyway.
         return False
+    package_root = os.path.dirname(os.path.dirname(path)) or '.'
     if template_type == 'cdbs':
         update_deb822(path, paragraph_cb=paragraph_cb, allow_generated=True)
     elif template_type == 'gnome':
-        dh_gnome_clean()
+        dh_gnome_clean(package_root)
     elif template_type == 'postgresql':
-        pg_buildext_updatecontrol()
+        pg_buildext_updatecontrol(package_root)
     elif template_type == 'lintian-brush-test':
         with open(template_path, 'rb') as inf, open(path, 'wb') as outf:
             outf.write(
@@ -210,16 +211,28 @@ def ensure_minimum_version(relationstr, package, minimum_version):
     Returns:
       updated relation string
     """
+    def is_obsolete(relation):
+        for r in relation:
+            if r.name != package:
+                continue
+            if r.version[0] == '>>' and r.version[1] < minimum_version:
+                return True
+            if r.version[0] == '>=' and r.version[1] <= minimum_version:
+                return True
+        return False
+
     minimum_version = Version(minimum_version)
     found = False
     changed = False
     relations = parse_relations(relationstr)
-    for (head_whitespace, relation, tail_whitespace) in relations:
+    obsolete_relations = []
+    for i, (head_whitespace, relation, tail_whitespace) in enumerate(
+            relations):
         if isinstance(relation, str):  # formatting
             continue
         names = [r.name for r in relation]
-        if len(names) > 1 and names[0] == package:
-            raise Exception("Complex rule for %s , aborting" % package)
+        if len(names) > 1 and package in names and is_obsolete(relation):
+            obsolete_relations.append(i)
         if names != [package]:
             continue
         found = True
@@ -232,6 +245,8 @@ def ensure_minimum_version(relationstr, package, minimum_version):
         _add_dependency(
             relations,
             [PkgRelation(name=package, version=('>=', minimum_version))])
+    for i in reversed(obsolete_relations):
+        del relations[i]
     if changed:
         return format_relations(relations)
     # Just return the original; we don't preserve all formatting yet.
