@@ -46,7 +46,7 @@ version=4
 https://github.com/jelmer/dulwich/tags/dulwich-(.*).tar.gz
 """)])
         self.assertEqual(
-            [('Repository', 'https://github.com/jelmer/dulwich', 'possible')],
+            [('Repository', 'https://github.com/jelmer/dulwich', 'likely')],
             list(guess_from_debian_watch('watch', False)))
 
 
@@ -179,3 +179,18 @@ class GuessRepoFromUrlTests(TestCase):
         self.assertEqual(
             'https://code.launchpad.net/bzr',
             guess_repo_from_url('http://launchpad.net/bzr/+download'))
+
+    def test_savannah(self):
+        self.assertEqual(
+            'https://git.savannah.gnu.org/git/auctex.git',
+            guess_repo_from_url('https://git.savannah.gnu.org/git/auctex.git'))
+        self.assertIs(
+            None,
+            guess_repo_from_url(
+                'https://git.savannah.gnu.org/blah/auctex.git'))
+
+    def test_bitbucket(self):
+        self.assertEqual(
+            'https://bitbucket.org/fenics-project/dolfin',
+            guess_repo_from_url(
+                'https://bitbucket.org/fenics-project/dolfin/downloads/'))
